@@ -8,13 +8,15 @@ fi
 #installing cipher module into newly created virtual env
 tmp_py_env=$(pwd)/temp_env
 python_bin=$(which python2)
-if [ "$python_bin" == "" ]; then
+if [ "$python_bin" = "" ]; then
     python_bin=$(which python)
 fi
 virtualenv -p $python_bin $tmp_py_env
 . $tmp_py_env/bin/activate
 tmp_cur_dir=$(pwd)
-cd $TOP/libs/cipher/cipher-1.7/
+CIPHER_DIR=$TOP/libs/cipher/cipher-1.7
+cd $CIPHER_DIR
+# the following creates "build dist .eggs" in $CIPHER_DIR
 $tmp_py_env/bin/python setup.py install
 cd $tmp_cur_dir
 unset tmp_cur_dir
@@ -43,4 +45,10 @@ deactivate
 rm -rf $tmp_py_env
 unset tmp_py_env
 
+cd $CIPHER_DIR
+rm -r  build dist .eggs
+rm -rf packit-0.18-py2.7.egg pbr-3.1.1-py2.7.egg wheel-0.30.0-py2.7.egg
+rm -v  cipher.egg-info/SOURCES.txt
+rm -vf glob2-0.4.1-py2.7.egg
+
 exit $exit_code
