@@ -971,7 +971,8 @@ FIXTURE_TEST_CASE(KConfigImportNgc_Basic, KfgFixture)
         const String* str;
         REQUIRE_RC(KConfigNodeReadVPath(GetNode("/repository/remote/protected/CGI/resolver-cgi"), &path));    
         REQUIRE_RC(VPathMakeString(path, &str));    
-        REQUIRE_EQ(string(str->addr), string("https://www.ncbi.nlm.nih.gov/Traces/names/names.cgi"));
+        REQUIRE_EQ(string(str->addr),
+            string("https://www.ncbi.nlm.nih.gov/Traces/names/names.fcgi"));
         StringWhack(str);
     }
     
