@@ -39,9 +39,9 @@ import ngs.ErrorMsg;
 
 import gov.nih.nlm.ncbi.ngs.NGS;
 
-//  The purpose of this suite is to verify integration of Java/JNI/C code, 
-//  for which running through just one type of archive is enough. 
-//  Thus these tests are not replicated for SRA and SRADB 
+//  The purpose of this suite is to verify integration of Java/JNI/C code,
+//  for which running through just one type of archive is enough.
+//  Thus these tests are not replicated for SRA and SRADB
 //  archives, unlike in the C-level test suites
 public class ngs_test_CSRA1 {
 
@@ -51,13 +51,13 @@ public class ngs_test_CSRA1 {
     String WithGroups            = "SRR822962";
     String WithCircularRef       = "SRR1769246";
     String SingleFragmentPerSpot = "SRR2096940";
-    
+
     @Test
     public void open_success() throws ngs.ErrorMsg
     {
         ngs.ReadCollection run = NGS . openReadCollection ( PrimaryOnly );
     }
-    
+
     @Test
     public void open_fail()
     {
@@ -66,33 +66,33 @@ public class ngs_test_CSRA1 {
             ngs.ReadCollection run = NGS . openReadCollection ( "SRRsomejunk" );
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReadCollection_getName() throws ngs.ErrorMsg
     {
         assertEquals ( PrimaryOnly, NGS . openReadCollection ( PrimaryOnly ) . getName () );
     }
-    
+
     @Test
     public void ReadCollection_getReadGroup() throws ngs.ErrorMsg
     {
         ngs.ReadGroup gr = NGS . openReadCollection ( PrimaryOnly ) . getReadGroup ( "C1ELY.6" );
     }
-    
+
     @Test
     public void ReadCollection_getReadGroups() throws ngs.ErrorMsg
     {
         ngs.ReadGroupIterator it = NGS . openReadCollection ( PrimaryOnly ) . getReadGroups ();
     }
-    
+
     @Test
     public void ReadCollection_getReferences() throws ngs.ErrorMsg
     {
         ngs.ReferenceIterator it = NGS . openReadCollection ( PrimaryOnly ) . getReferences ();
     }
-    
+
     @Test
     public void ReadCollection_getReference() throws ngs.ErrorMsg
     {
@@ -105,13 +105,13 @@ public class ngs_test_CSRA1 {
         assert ( NGS . openReadCollection ( PrimaryOnly ) . hasReference ( "supercont2.1" ) );
         assert ( ! NGS . openReadCollection ( PrimaryOnly ) . hasReference ( "non-existent acc" ) );
     }
-    
+
     @Test
     public void ReadCollection_getAlignment() throws ngs.ErrorMsg
     {
         ngs.Alignment al = NGS . openReadCollection ( PrimaryOnly ) . getAlignment( PrimaryOnly + ".PA.1" );
     }
-    
+
     @Test
     public void ReadCollection_getAlignments_Primary() throws ngs.ErrorMsg
     {
@@ -148,7 +148,7 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( 3987701, NGS . openReadCollection ( PrimaryOnly ) . getAlignmentCount ( Alignment . all ) );
     }
-    
+
     @Test
     public void ReadCollection_getAlignmentCount_WithSecondary() throws ngs.ErrorMsg
     {
@@ -169,7 +169,7 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( 178, NGS . openReadCollection ( WithSecondary ) . getAlignmentCount ( Alignment . all ) );
     }
-    
+
     @Test
     public void ReadCollection_getAlignmentRange() throws ngs.ErrorMsg
     {   // straddling primary and secondary alignments
@@ -177,44 +177,44 @@ public class ngs_test_CSRA1 {
         assertTrue ( alIt . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.166", alIt . getAlignmentId () );
     }
-    
+
     @Test
     public void ReadCollection_getRead () throws ngs.ErrorMsg
-    {   
+    {
         ngs . Read read = NGS . openReadCollection ( PrimaryOnly ) . getRead ( PrimaryOnly + ".R.1" );
         assertEquals ( PrimaryOnly + ".R.1", read . getReadId () );
     }
 
     @Test
     public void ReadCollection_getReads () throws ngs.ErrorMsg
-    {   
+    {
         ngs . ReadIterator readIt = NGS . openReadCollection ( PrimaryOnly ) . getReads( ngs . Read . all );
         assertTrue ( readIt . nextRead () );
         assertEquals ( PrimaryOnly + ".R.1", readIt . getReadId () );
     }
-    
+
     @Test
     public void ReadCollection_getReadCount () throws ngs.ErrorMsg
-    {   
+    {
         assertEquals ( 2280633, NGS . openReadCollection ( PrimaryOnly ) . getReadCount () );
     }
-    
+
     @Test
     public void ReadCollection_getReadRange () throws ngs.ErrorMsg
-    {   
+    {
         ngs . ReadIterator readIt = NGS . openReadCollection ( PrimaryOnly ) . getReadRange ( 2, 3 );
         assertTrue ( readIt . nextRead () );
         assertEquals ( PrimaryOnly + ".R.2", readIt . getReadId () );
     }
 
-// Read 
+// Read
 
     ngs.Read getRead ( String id ) throws ngs.ErrorMsg
     {
         ngs.ReadCollection run = NGS . openReadCollection ( PrimaryOnly );
         return run . getRead(id);
     }
-    
+
     @Test
     public void Read_getReadCategory_full() throws ngs.ErrorMsg
     {
@@ -225,13 +225,13 @@ public class ngs_test_CSRA1 {
     {
         assertEquals( ngs . Read . partiallyAligned, getRead( PrimaryOnly + ".R.3" ) . getReadCategory() );
     }
-    
+
     @Test
     public void Read_getNumFragments() throws ngs.ErrorMsg
     {
         assertEquals( 2, getRead( PrimaryOnly + ".R.1" ) . getNumFragments() );
     }
-    
+
     @Test
     public void Read_fragmentIsAligned_partial() throws ngs.ErrorMsg
     {
@@ -244,12 +244,12 @@ public class ngs_test_CSRA1 {
     @Test
     public void FragmentIterator_ThrowsBeforeNext() throws ngs.ErrorMsg
     {
-        try 
+        try
         {
             getRead( PrimaryOnly + ".R.1" ) . getFragmentId();
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
     @Test
     public void FragmentIterator_Next() throws ngs.ErrorMsg
@@ -266,7 +266,7 @@ public class ngs_test_CSRA1 {
         assertTrue ( read . nextFragment () );
         assertEquals( PrimaryOnly + ".FR0.1", read . getFragmentId () );
     }
-    
+
     @Test
     public void getFragmentBases() throws ngs.ErrorMsg
     {
@@ -275,7 +275,7 @@ public class ngs_test_CSRA1 {
         assertTrue ( read . nextFragment () );
         assertEquals( "GGTA", read . getFragmentBases ( 2, 4 ) );
     }
-    
+
     @Test
     public void getFragmentQualities() throws ngs.ErrorMsg
     {
@@ -285,9 +285,9 @@ public class ngs_test_CSRA1 {
         assertEquals( "@DDA", read . getFragmentQualities ( 2, 4 ) );
     }
 
-    
+
 // Alignment
-    
+
     ngs.Alignment getAlignment ( String id ) throws ngs.ErrorMsg
     {
         ngs.ReadCollection run = NGS . openReadCollection ( PrimaryOnly );
@@ -304,7 +304,7 @@ public class ngs_test_CSRA1 {
     {
         assertEquals( PrimaryOnly + ".PA.1", getAlignment ( PrimaryOnly + ".PA.1" ).getAlignmentId() );
     }
-    
+
     @Test
     public void Alignment_getReferenceSpec() throws ngs.ErrorMsg
     {
@@ -316,20 +316,20 @@ public class ngs_test_CSRA1 {
     {
         assertEquals( 60, getAlignment ( PrimaryOnly + ".PA.1" ).getMappingQuality() );
     }
-    
+
     @Test
     public void Alignment_getReferenceBases() throws ngs.ErrorMsg
     {
-        assertEquals( "ACTCGACATTCTGTCTTCGACCTATCTTTCTCCTCTCCCAGTCATCGCCCAGTAGAATTACCAGGCAATGAACCACGGCCTTTCATCCCAACGGCACAGCA", 
+        assertEquals( "ACTCGACATTCTGTCTTCGACCTATCTTTCTCCTCTCCCAGTCATCGCCCAGTAGAATTACCAGGCAATGAACCACGGCCTTTCATCCCAACGGCACAGCA",
                       getAlignment ( PrimaryOnly + ".PA.1" ).getReferenceBases() );
     }
-    
+
     @Test
     public void Alignment_getReadGroup() throws ngs.ErrorMsg
     {
         assertEquals( "C1ELY.6", getAlignment ( PrimaryOnly + ".PA.1" ).getReadGroup() );
     }
-    
+
     @Test
     public void Alignment_getReadId() throws ngs.ErrorMsg
     {
@@ -341,60 +341,60 @@ public class ngs_test_CSRA1 {
     {
         assertEquals( PrimaryOnly + ".FA0.1", getAlignment ( PrimaryOnly + ".PA.1" ) . getFragmentId () );
     }
-    
+
     @Test
     public void Alignment_getFragmentBases_Raw() throws ngs.ErrorMsg
     {
-        assertEquals( "TGGATGCTCTGGAAAATCTGAAAAGTGGTGTTTGTAAGGTTTGCTGGCTGCCCATATACCACATGGATGATGGGGCTTTCCATTTTAATGTTGAAGGAGGA", 
+        assertEquals( "TGGATGCTCTGGAAAATCTGAAAAGTGGTGTTTGTAAGGTTTGCTGGCTGCCCATATACCACATGGATGATGGGGCTTTCCATTTTAATGTTGAAGGAGGA",
                       getAlignment ( PrimaryOnly + ".PA.4" ).getFragmentBases () );
     }
-    
+
     @Test
     public void Alignment_getFragmentQualities_Raw() throws ngs.ErrorMsg
     {
-        assertEquals( "######AA>55;5(;63;;3@;A9??;6..73CDCIDA>DCB>@B=;@B?;;ADAB<DD?1*>@C9:EC?2++A3+F4EEB<E>EEIEDC2?C:;AB+==1", 
+        assertEquals( "######AA>55;5(;63;;3@;A9??;6..73CDCIDA>DCB>@B=;@B?;;ADAB<DD?1*>@C9:EC?2++A3+F4EEB<E>EEIEDC2?C:;AB+==1",
                       getAlignment ( PrimaryOnly + ".PA.4" ).getFragmentQualities () );
     }
-    
+
     @Test
     public void Alignment_getFragmentBases_Clipped() throws ngs.ErrorMsg
     {
-        assertEquals( "CTTCAACATTAAAATGGAAAGCCCCATCATCCATGTGGTATATGGGCAGCCAGCAAACCTTACAAACACCACTTTTCAGATTTTCCAGAGCATCCA", 
+        assertEquals( "CTTCAACATTAAAATGGAAAGCCCCATCATCCATGTGGTATATGGGCAGCCAGCAAACCTTACAAACACCACTTTTCAGATTTTCCAGAGCATCCA",
                       getAlignment ( PrimaryOnly + ".PA.4" ).getClippedFragmentBases () );
     }
-    
+
     @Test
     public void Alignment_getFragmentQualities_Clipped() throws ngs.ErrorMsg
     {
-        assertEquals( "#AA>55;5(;63;;3@;A9??;6..73CDCIDA>DCB>@B=;@B?;;ADAB<DD?1*>@C9:EC?2++A3+F4EEB<E>EEIEDC2?C:;AB+==1", 
+        assertEquals( "#AA>55;5(;63;;3@;A9??;6..73CDCIDA>DCB>@B=;@B?;;ADAB<DD?1*>@C9:EC?2++A3+F4EEB<E>EEIEDC2?C:;AB+==1",
                       getAlignment ( PrimaryOnly + ".PA.4" ).getClippedFragmentQualities () );
     }
 
     @Test
     public void Alignment_getAlignedFragmentBases() throws ngs.ErrorMsg
     {
-        assertEquals( "ATATGGGTTCACTCCAACAGTGAACCATTCCAAAAGACCTTGCCTGCGTGGCCATCTCCTCACAAACCCACCATCCCGCAACATCTCAGGTATCATACCTT", 
+        assertEquals( "ATATGGGTTCACTCCAACAGTGAACCATTCCAAAAGACCTTGCCTGCGTGGCCATCTCCTCACAAACCCACCATCCCGCAACATCTCAGGTATCATACCTT",
                       getAlignment ( PrimaryOnly + ".PA.2" ).getAlignedFragmentBases () );
     }
-    
+
     @Test
     public void Alignment_getAlignmentCategory() throws ngs.ErrorMsg
     {
         assertEquals( ngs . Alignment . primaryAlignment, getAlignment ( PrimaryOnly + ".PA.4" ).getAlignmentCategory () );
     }
-    
+
     @Test
     public void Alignment_getAlignmentPosition() throws ngs.ErrorMsg
     {
         assertEquals( 85, getAlignment ( PrimaryOnly + ".PA.1" ).getAlignmentPosition () );
     }
-    
+
     @Test
     public void Alignment_getAlignmentLength() throws ngs.ErrorMsg
     {
         assertEquals( 101, getAlignment ( PrimaryOnly + ".PA.1" ).getAlignmentLength () );
     }
-    
+
     @Test
     public void Alignment_getIsReversedOrientation_False() throws ngs.ErrorMsg
     {
@@ -405,7 +405,7 @@ public class ngs_test_CSRA1 {
     {
         assertTrue( getAlignment ( PrimaryOnly + ".PA.2" ).getIsReversedOrientation () );
     }
-    
+
     @Test
     public void Alignment_getSoftClip_None() throws ngs.ErrorMsg
     {
@@ -427,13 +427,13 @@ public class ngs_test_CSRA1 {
         assertEquals( 0,  al . getSoftClip ( ngs . Alignment . clipLeft ) );
         assertEquals( 13, al . getSoftClip ( ngs . Alignment . clipRight ) );
     }
-    
+
     @Test
     public void Alignment_getTemplateLength() throws ngs.ErrorMsg
     {
         assertEquals( 201, getAlignment ( PrimaryOnly + ".PA.1" ).getTemplateLength () );
     }
-    
+
     @Test
     public void Alignment_getShortCigar_Unclipped() throws ngs.ErrorMsg
     {
@@ -455,7 +455,7 @@ public class ngs_test_CSRA1 {
     {
         assertEquals( "1X8=1X39=1X46=", getAlignment ( PrimaryOnly + ".PA.4" ).getLongCigar ( true ) );
     }
-    
+
     @Test
     public void Alignment_hasMate_Primary_No() throws ngs.ErrorMsg
     {
@@ -485,7 +485,7 @@ public class ngs_test_CSRA1 {
             getAlignment ( PrimaryOnly + ".PA.99" ) . getMateAlignmentId ( );
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
     @Test
     public void Alignment_getMateAlignmentId_SecondaryThrows() throws ngs.ErrorMsg
@@ -495,9 +495,9 @@ public class ngs_test_CSRA1 {
             getSecondaryAlignment ( WithSecondary + ".SA.172" ) . getMateAlignmentId ( );
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void Alignment_getMateAlignment() throws ngs.ErrorMsg
     {
@@ -506,30 +506,30 @@ public class ngs_test_CSRA1 {
     @Test
     public void Alignment_getMateAlignment_Missing() throws ngs.ErrorMsg
     {
-        try 
+        try
         {
             getAlignment ( PrimaryOnly + ".PA.99" ) . getMateAlignment ();
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
     @Test
     public void Alignment_getMateAlignment_SecondaryThrows() throws ngs.ErrorMsg
     {
-        try 
+        try
         {
             getSecondaryAlignment ( WithSecondary +".SA.172" ) . getMateAlignment ();
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void Alignment_getMateReferenceSpec() throws ngs.ErrorMsg
     {
         assertEquals ( "supercont2.1",  getAlignment ( PrimaryOnly + ".PA.1" ) . getMateReferenceSpec () );
     }
-    
+
     @Test
     public void Alignment_getMateIsReversedOrientation_Yes() throws ngs.ErrorMsg
     {
@@ -540,22 +540,22 @@ public class ngs_test_CSRA1 {
     {
         assertFalse( getAlignment ( PrimaryOnly + ".PA.2" ) . getMateIsReversedOrientation () );
     }
-    
+
     @Test
     public void Alignment_isPaired_MultiFragmentsPerSpot() throws ngs.ErrorMsg
     {
         ngs . ReadCollection readCollection = NGS . openReadCollection ( PrimaryOnly );
         ngs . Alignment alignment = readCollection . getAlignment ( PrimaryOnly + ".PA.1" );
         assertTrue( alignment.isPaired() );
-        
+
         alignment = readCollection . getAlignment ( PrimaryOnly + ".PA.2" );
         assertTrue( alignment.isPaired() );
-        
+
         // has unaligned mate
         alignment = readCollection . getAlignment ( PrimaryOnly + ".PA.6" );
         assertTrue( alignment.isPaired() );
     }
-    
+
     @Test
     public void Alignment_isPaired_SingleFragmentPerSpot() throws ngs.ErrorMsg
     {
@@ -576,19 +576,19 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( "gi|218511148|ref|NC_011752.1|", getReferenceSequence () . getCanonicalName () );
     }
-    
+
     @Test
     public void ReferenceSequence_getIsCircular_Yes() throws ngs.ErrorMsg
     {
         assertTrue( getReferenceSequence () . getIsCircular () );
     }
-    
+
     @Test
     public void ReferenceSequence_getLength() throws ngs.ErrorMsg
     {
         assertEquals ( 72482, getReferenceSequence () . getLength() );
     }
-    
+
     @Test
     public void ReferenceSequence_getReferenceBases() throws ngs.ErrorMsg
     {
@@ -599,7 +599,7 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( "TACA", getReferenceSequence () . getReferenceBases ( 4998, 4 ) );
     }
-    
+
     @Test
     public void ReferenceSequence_getReferenceChunk() throws ngs.ErrorMsg
     {
@@ -623,13 +623,13 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( "supercont2.1", getReference () . getCommonName () );
     }
-    
+
     @Test
     public void Reference_getCanonicalName () throws ngs.ErrorMsg
     {
         assertEquals ( "NC_000007.13", NGS . openReadCollection ( "SRR821492" ) . getReference ( "chr7" ) . getCanonicalName () );
     }
-    
+
     @Test
     public void Reference_getIsCircular_No() throws ngs.ErrorMsg
     {
@@ -640,13 +640,13 @@ public class ngs_test_CSRA1 {
     {
         assertTrue( NGS . openReadCollection ( "SRR821492" ) . getReference ( "chrM" ) . getIsCircular () );
     }
-    
+
     @Test
     public void Reference_getLength() throws ngs.ErrorMsg
     {
         assertEquals ( 2291499l, getReference () . getLength() );
     }
-    
+
     @Test
     public void Reference_getReferenceBases() throws ngs.ErrorMsg
     {
@@ -657,7 +657,7 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( "GCGCTATGAC", getReference () . getReferenceBases ( 9000, 10 ) );
     }
-    
+
     @Test
     public void Reference_getReferenceChunk() throws ngs.ErrorMsg
     {
@@ -668,13 +668,13 @@ public class ngs_test_CSRA1 {
     {
         assertEquals ( "GCGCTATGAC", getReference () . getReferenceChunk ( 9000, 10 ) );
     }
-    
+
     @Test
     public void Reference_getAlignment() throws ngs.ErrorMsg
     {
         assertEquals ( PrimaryOnly + ".PA.1", getReference () . getAlignment ( PrimaryOnly + ".PA.1" ) . getAlignmentId () );
     }
-    
+
 //TODO: getPileups
 //TODO: getPileupSlice
 //TODO: getPileupSlice_Filtered
@@ -685,14 +685,14 @@ public class ngs_test_CSRA1 {
     public void ReferenceIterator_ThrowBeforeNext() throws ngs.ErrorMsg
     {
         ngs.ReferenceIterator it = NGS . openReadCollection ( PrimaryOnly ) . getReferences ();
-        try 
+        try
         {
             it . getCommonName ();
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReferenceIterator_Next() throws ngs.ErrorMsg
     {
@@ -700,16 +700,16 @@ public class ngs_test_CSRA1 {
         assertTrue ( it . nextReference () );
         assertEquals ( "supercont2.1", it . getCommonName () );
     }
-    
+
 // AlignmentIterator from Reference (ReferenceWindow)
     @Test
     public void ReferenceWindow () throws ngs.ErrorMsg
     {
-        ngs.AlignmentIterator it = NGS . openReadCollection ( WithSecondary ) 
+        ngs.AlignmentIterator it = NGS . openReadCollection ( WithSecondary )
                                         . getReference ( "gi|169794206|ref|NC_010410.1|" )
-                                        . getAlignments ( ngs . Alignment . all ); 
-        assertTrue ( it . nextAlignment () );  
-    
+                                        . getAlignments ( ngs . Alignment . all );
+        assertTrue ( it . nextAlignment () );
+
         // the first 2 secondary alignments' locations on the list: #34, #61
         long count = 1;
         while ( it . nextAlignment() )
@@ -718,78 +718,78 @@ public class ngs_test_CSRA1 {
                 break;
             ++count;
         }
-        assertEquals ( 34, count);    
+        assertEquals ( 34, count);
         while ( it . nextAlignment() )
         {
             if ( it . getAlignmentCategory()  == ngs . Alignment . secondaryAlignment )
                 break;
             ++count;
         }
-        assertEquals ( 61, count);    
+        assertEquals ( 61, count);
     }
-    
+
     @Test
     public void ReferenceWindow_Slice () throws ngs.ErrorMsg
     {
-        ngs.AlignmentIterator it = NGS . openReadCollection ( WithSecondary ) 
+        ngs.AlignmentIterator it = NGS . openReadCollection ( WithSecondary )
                                         . getReference ( "gi|169794206|ref|NC_010410.1|" )
-                                        . getAlignmentSlice ( 516000, 100000 ); 
-        assertTrue ( it . nextAlignment () );  
+                                        . getAlignmentSlice ( 516000, 100000 );
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.33", it. getAlignmentId () );
-        assertTrue ( it . nextAlignment () );  
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.34", it. getAlignmentId () );
-        assertTrue ( it . nextAlignment () );  
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".SA.169", it. getAlignmentId () ); //secondary
-        assertTrue ( it . nextAlignment () );  
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.35", it. getAlignmentId () );
-        assertFalse ( it . nextAlignment () );  
+        assertFalse ( it . nextAlignment () );
     }
-   
+
     @Test
     public void ReferenceWindow_Slice_Filtered_Category () throws ngs.ErrorMsg
     {
-        ngs.AlignmentIterator it = NGS . openReadCollection ( WithSecondary ) 
+        ngs.AlignmentIterator it = NGS . openReadCollection ( WithSecondary )
                                         . getReference ( "gi|169794206|ref|NC_010410.1|" )
-                                        . getAlignmentSlice ( 516000, 100000, ngs . Alignment . primaryAlignment ); 
-        assertTrue ( it . nextAlignment () );  
+                                        . getAlignmentSlice ( 516000, 100000, ngs . Alignment . primaryAlignment );
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.33", it. getAlignmentId () );
-        assertTrue ( it . nextAlignment () );  
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.34", it. getAlignmentId () );
-        assertTrue ( it . nextAlignment () );  
+        assertTrue ( it . nextAlignment () );
         assertEquals ( WithSecondary + ".PA.35", it. getAlignmentId () ); // no secondary
-        assertFalse ( it . nextAlignment () );  
+        assertFalse ( it . nextAlignment () );
     }
-    
+
     @Test
     public void ReferenceWindow_Slice_Filtered_Start_Within_Slice () throws ngs.ErrorMsg
     {
         ngs.Reference ref = NGS . openReadCollection ( WithCircularRef )
                                  . getReference ( "NC_012920.1" );
-        ngs.AlignmentIterator it = ref . getFilteredAlignmentSlice ( 0, ref.getLength(), Alignment . all, Alignment . startWithinSlice, 0 );
-    
+        ngs.AlignmentIterator it = ref . getFilteredAlignmentSlice ( 0, ref.getLength(), Alignment . all, Alignment . noWraparound, 0 );
+
         assertTrue ( it . nextAlignment () );
         long numberOfFilteredAlignments = 1;
         long lastAlignmentPosition = it.getAlignmentPosition();
         while ( it . nextAlignment () ) {
             long currentPosition = it.getAlignmentPosition();
-            
+
             String errorMsg = "Sorting violated. Last position (" + lastAlignmentPosition + ") is higher than current one (" + currentPosition + ")";
             assertTrue ( errorMsg, lastAlignmentPosition <= currentPosition );
-            
+
             lastAlignmentPosition = currentPosition;
             numberOfFilteredAlignments++;
         }
-        
+        assertEquals ( "numberOfFilteredAlignments ", numberOfFilteredAlignments, 12315 );
+
         it = ref . getFilteredAlignmentSlice ( 0, ref.getLength(), Alignment . all, 0, 0 );
         long numberOfUnfilteredAlignments = 0;
         while ( it . nextAlignment () ) {
             numberOfUnfilteredAlignments++;
         }
-        
-        assertEquals ( numberOfUnfilteredAlignments, 12317 );
-        assertEquals ( numberOfFilteredAlignments, 12316 );
+
+        assertEquals ( "numberOfUnfilteredAlignments ", numberOfUnfilteredAlignments, 12316 );
     }
-    
+
     // ReadGroup
     @Test
     public void ReadGroup_getName () throws ngs.ErrorMsg
@@ -809,12 +809,12 @@ public class ngs_test_CSRA1 {
         ngs.ReadGroup gr = NGS . openReadCollection ( WithGroups ) . getReadGroup ( "GS57510-FS3-L03" );
 
         ngs . Statistics stats = gr . getStatistics ();
-    
+
         assertEquals ( 34164461870L, stats . getAsU64 ( "BASE_COUNT" ) );
         assertEquals ( 34164461870L, stats . getAsU64 ( "BIO_BASE_COUNT" ) );
         assertEquals ( 488063741L,   stats . getAsU64 ( "SPOT_COUNT" ) );
         assertEquals ( 5368875807L,  stats . getAsU64 ( "SPOT_MAX" ) );
-        assertEquals ( 4880812067L,  stats . getAsU64 ( "SPOT_MIN" ) );        
+        assertEquals ( 4880812067L,  stats . getAsU64 ( "SPOT_MIN" ) );
     }
 
 /* ReadGroup no longer supports Reads
@@ -825,7 +825,7 @@ public class ngs_test_CSRA1 {
         ngs.Read r = gr . getRead ( PrimaryOnly + ".R.1" );
         assertEquals ( "C1ELY.6", r . getReadGroup () );
     }
-    
+
     @Test
     public void ReadGroup_getReads () throws ngs.ErrorMsg
     {
@@ -833,20 +833,20 @@ public class ngs_test_CSRA1 {
         ngs.ReadIterator r = gr . getReads ( ngs . Read . partiallyAligned );
     }
 */
-    
+
     // ReadGroupIterator
     @Test
     public void ReadGroupIterator_ThrowBeforeNext() throws ngs.ErrorMsg
     {
         ngs.ReadGroupIterator it = NGS . openReadCollection ( PrimaryOnly ) . getReadGroups ();
-        try 
+        try
         {
             it . getName ();
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}        
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReadGroupIterator_Next() throws ngs.ErrorMsg
     {
@@ -858,99 +858,99 @@ public class ngs_test_CSRA1 {
         assertTrue ( r . nextRead () );
         assertEquals ( name, r . getReadGroup () );
 */
-    }    
-    
+    }
+
     @Test
     public void ReadCollection_openReadCollection_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		NGS.openReadCollection(null);
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}   
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReadCollection_setAppVersion_null() throws ngs.ErrorMsg
     {
 		NGS.setAppVersionString(null);
     }
-    
+
     @Test
     public void ReadCollection_openReferenceSequence_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		NGS.openReferenceSequence(null);
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}   
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReadCollection_isValid_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		NGS.isValid(null);
             fail();
         }
-        catch ( NullPointerException e ) {}   
+        catch ( NullPointerException e ) {}
     }
-    
+
     @Test
     public void ReadCollection_hasReadGroup_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		ReadCollection run = NGS.openReadCollection(PrimaryOnly);
             run.hasReadGroup(null);
         }
-        catch ( ngs.ErrorMsg e ) 
+        catch ( ngs.ErrorMsg e )
     	{
         	fail();
-        }   
+        }
     }
-    
+
     @Test
     public void ReadCollection_hasReference_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		ReadCollection run = NGS.openReadCollection(PrimaryOnly);
     		run.hasReference(null);
         }
-        catch ( ngs.ErrorMsg e ) 
+        catch ( ngs.ErrorMsg e )
     	{
         	fail();
-    	}   
+    	}
     }
-    
+
     @Test
     public void ReadCollection_getReference_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		ReadCollection run = NGS.openReadCollection(PrimaryOnly);
     		run.getReference(null);
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}   
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReadCollection_getAlignment_null() throws ngs.ErrorMsg
     {
-    	try 
+    	try
         {
     		ReadCollection run = NGS.openReadCollection(PrimaryOnly);
     		run.getAlignment(null);
             fail();
         }
-        catch ( ngs.ErrorMsg e ) {}   
+        catch ( ngs.ErrorMsg e ) {}
     }
-    
+
     @Test
     public void ReadCollection_ReadGroup_Statistics_getValueType_null() throws ngs.ErrorMsg
     {
