@@ -35,6 +35,8 @@
 
 #include <kdb/manager.h>
 
+#include <kfg/config.h> /* KConfigDisableUserSettings */
+
 #include <vdb/manager.h>
 #include <vdb/vdb-priv.h>
 
@@ -569,6 +571,7 @@ const char UsageDefaultName[] = "test-ngs_csra1_pileup";
 
 rc_t CC KMain ( int argc, char *argv [] )
 {
+    KConfigDisableUserSettings();
     rc_t m_coll=NgsCsra1PileupTestSuite(argc, argv);
     return m_coll;
 }
