@@ -36,6 +36,8 @@
 
 #include <kdb/manager.h>
 
+#include <kfg/config.h> /* KConfigDisableUserSettings */
+
 #include <vdb/manager.h>
 #include <vdb/vdb-priv.h>
 
@@ -731,6 +733,7 @@ const char UsageDefaultName[] = "test-ngs_csra1_readcollection";
 
 rc_t CC KMain ( int argc, char *argv [] )
 {
+    KConfigDisableUserSettings();
     rc_t m_coll=NgsCsra1ReadCollectionTestSuite(argc, argv);
     return m_coll;
 }
