@@ -28,6 +28,7 @@
 * Unit tests for VResolver interface
 */
 
+#include <kapp/args.h> /* ArgsMakeAndHandle */
 
 #include <klib/text.h>
 
@@ -42,6 +43,8 @@
 #include <vfs/resolver.h>
 #include <vfs/path.h>
 
+#include "resolver-cgi.h" /* RESOLVER_CGI */
+
 #include <cstdlib>
 #include <fstream>
 #include <stdexcept>
@@ -50,7 +53,14 @@
 
 #include <sysalloc.h>
 
-TEST_SUITE(VResolverTestSuite);
+#define RELEASE(type, obj) do { rc_t rc2 = type##Release(obj); \
+    if (rc2 != 0 && rc == 0) { rc = rc2; } obj = NULL; } while (false)
+
+static rc_t argsHandler(int argc, char* argv[]) {
+    return ArgsMakeAndHandle ( NULL, argc, argv, 0, NULL, 0 );
+}
+
+TEST_SUITE_WITH_ARGS_HANDLER(VResolverTestSuite, argsHandler);
 
 using namespace std;
 
@@ -220,6 +230,13 @@ public:
         if (KConfigMake(&cfg, wd))
             throw logic_error ( "ResolverFixtureCustomConfig::Configure: KConfigMake failed" );
 
+        if (KConfigWriteString ( cfg,
+                "repository/remote/main/CGI/resolver-cgi", RESOLVER_CGI))
+        {
+            throw logic_error ( "ResolverFixtureCustomConfig::Configure:"
+                " KConfigWriteString failed" );
+        }
+
         if (VFSManagerMakeFromKfg(&vfs, cfg))
             throw logic_error ( "ResolverFixtureCustomConfig::Configure: VFSManagerMakeFromKfg failed" );
 
@@ -304,6 +321,7 @@ FIXTURE_TEST_CASE(VDB_2963_resolve_local_no_new_wgs, ResolverFixtureCustomConfig
 }
 
 //////////////////////////////////////////// Main
+
 extern "C"
 {
 
@@ -340,8 +358,12 @@ extern "C"
 
     rc_t CC KMain ( int argc, char *argv [] )
     {
+        KConfigDisableUserSettings ();
+
         rc_t rc = VResolverTestSuite ( argc, argv );
+
         clear_recorded_errors();
+
         return rc;
     }
 
