@@ -25,22 +25,33 @@
 */
 
 
-#include <klib/time.h> /* KTimeMakeTime */
-#include <vfs/services-priv.h> /* KServiceTestNamesExecuteExt */
 #include "../../libs/vfs/services-priv.h" /* KServiceNames3_0StreamTest */
 #include "../../libs/vfs/path-priv.h" /* VPathEqual */
-#include <vfs/services.h> /* KSrvResponse */
-#include <vfs/path.h> /* VPath */
+#include <kapp/args.h> /* ArgsMakeAndHandle */
+#include <kfg/config.h> /* KConfigDisableUserSettings */
 #include <klib/debug.h> /* KDbgSetString */
 #include <klib/rc.h>
 #include <klib/text.h> /* CONST_STRING */
+#include <klib/time.h> /* KTimeMakeTime */
 #include <ktst/unit_test.hpp> /* KMain */
+#include <vfs/path.h> /* VPath */
+#include <vfs/services.h> /* KSrvResponse */
+#include <vfs/services-priv.h> /* KServiceTestNamesExecuteExt */
+
+#include "resolver-cgi.h" /* RESOLVER_CGI */
 
 //#include <cstdio> // printf
 
 using std :: string;
 
-TEST_SUITE ( Names3_0_TestSuite );
+static rc_t argsHandler(int argc, char* argv[]) {
+    return ArgsMakeAndHandle ( NULL, argc, argv, 0, NULL, 0 );
+}
+
+TEST_SUITE_WITH_ARGS_HANDLER ( Names3_0_TestSuite, argsHandler );
+
+#define RELEASE(type, obj) do { rc_t rc2 = type##Release(obj); \
+    if (rc2 != 0 && rc == 0) { rc = rc2; } obj = NULL; } while (false)
 
 class P {
     String _tick;
@@ -426,6 +437,8 @@ TEST_CASE ( AND_ERROR ) {
 }
 #endif
 
+static KConfig * KFG = NULL;
+
 TEST_CASE ( FULL_TEST_NO_HTTP ) {
 //  assert ( ! KDbgSetString ( "VFS" ) );
 
@@ -439,6 +452,7 @@ TEST_CASE ( FULL_TEST_NO_HTTP ) {
         NULL, NULL ) );
 
     const KSrvResponse * response = NULL;
+
 if ( 1 )
     REQUIRE_RC_FAIL ( KServiceTestNamesExecuteExt ( service, 0, NULL, NULL,
         & response, "" ) );
@@ -491,13 +505,24 @@ if ( 1 )
         NULL, NULL ) );
 }
 
-TEST_CASE ( TEST_KFG ) {
-}
-
 extern "C" {
+    const char UsageDefaultName[] = "test-names-30";
+    rc_t CC UsageSummary ( const char     * progname) { return 0; }
+    rc_t CC Usage        ( const struct Args * args ) { return 0; }
     ver_t CC KAppVersion ( void ) { return 0; }
     rc_t CC KMain ( int argc, char * argv [] ) {
         if ( 0 ) assert ( ! KDbgSetString ( "VFS" ) );
-        return Names3_0_TestSuite ( argc, argv );
+        KConfigDisableUserSettings ();
+
+        rc_t rc = KConfigMake ( & KFG, NULL );
+        if ( rc == 0 )
+            rc = KConfigWriteString ( KFG,
+                "repository/remote/main/CGI/resolver-cgi", RESOLVER_CGI );
+
+        rc = Names3_0_TestSuite ( argc, argv );
+
+        RELEASE ( KConfig, KFG );
+
+        return rc;
     }
 }
